@@ -64,11 +64,14 @@ class Derivative:
 
 class Velocity:
     def __init__(self):
-        self.Velocities = None
+        self.Velocities = []
 
     def pop(self):
         self.Velocities = []
 
+    def add(self, val):
+        self.Velocities.append(val)
+
 class MomentEstimate:
     def __init__(self):
         self.moment_estimate_1 = []
@@ -78,6 +81,44 @@ class MomentEstimate:
         self.Velocities = []
 
 
+class FirstMoment:
+    def __init__(self):
+        self.Moments = []
+
+    def pop(self):
+        self.Moments = []
+
+    def add(self, val):
+        self.Moments.append(val)
+
+
+class SecondMoment:
+    def __init__(self):
+        self.Moments = []
+
+    def pop(self):
+        self.Moments = []
+
+    def add(self, val):
+        self.Moments.append(val)
+
+
+class LocalNetValues:
+    def __init__(self):
+        self.VelocityVals = Velocity()
+        self.ActivationList = []
+        self.DropoutList = []
+        self.l1PenaltyList = []
+        self.l2PenaltyList = []
+        self.ActivationDerivativeList = []
+        self.ActivationListString = []
+        self.ActivationDerivativeListString = []
+        self.OptimizerString = ['gradient decent']
+        self.LossString = ['mean square error']
+        self. Loss = [[]]
+        self.Optimizer = []
+
+
 # GLOBAL NETWORK VALUES
 WeightVals = Weight()
 KernelVals = Kernel()
@@ -85,6 +126,9 @@ LayerVals = Layer()
 NeuronVals = Neuron()
 DerivativeVals = Derivative()
 MomentEstimateVals = MomentEstimate()
+LocalValues = LocalNetValues()
+FirstMomentVals = FirstMoment()
+SecondMomentVals = SecondMoment()
 # LOCAL NETWORK VALUES
 VelocityVals = Velocity()
 ActivationList = []
@@ -98,6 +142,7 @@ OptimizerString = ['gradient decent']
 LossString = ['mean square error']
 Loss = [[]]
 Optimizer = []
+DistanceIndex = [0]
 
 # cost, acc, rel_error, epoch
 NetworkMetrics=[[], [], [], []]
