@@ -1,7 +1,7 @@
 from deeprai.engine.base_layer import WeightVals, LayerVals, KernelVals, ActivationList, ActivationDerivativeList, \
     NeuronVals, \
     DerivativeVals, ActivationListString, ActivationDerivativeListString, Loss, DropoutList, l1PenaltyList, \
-    l2PenaltyList
+    l2PenaltyList, DistanceIndex
 import deeprai.engine.cython.activation as act
 from deeprai.engine.cython import optimizers as opt
 from deeprai.engine.cython import loss as lossFunc
@@ -43,7 +43,7 @@ class Build:
         Loss[0] = (lambda o, t: self.LossMap[lossF[0]](o, t))
 
     def create_dense(self, size, activation='sigmoid', dropout=0, l1_penalty=0, l2_penalty=0):
-        # creats activation map
+        # creates activation map
         ActivationListString.append(activation)
         ActivationDerivativeListString.append(activation)
         DropoutList.append(float(dropout))
@@ -67,8 +67,18 @@ class Build:
             del l1PenaltyList[0]
             # input neuron
 
+    def translate_distance(self, distance):
+        DistanceMap = {
+            "euclidean distance": 0,
+            "manhattan distance": 1,
+            "minkowski distance": 2,
+            "hamming distance": 3
+        }
+        # Directly modify the external DistanceIndex variable
+        DistanceIndex[0] = DistanceMap[distance]
+
     def create_flat(self):
         pass
 
     def create_merge(self):
-        pass
+        pass
\ No newline at end of file
